@@ -72,7 +72,10 @@ class MigrationBase(base.BaseSharesAdminTest):
                                     "needed to run share migration tests.")
 
         # create share type (generic)
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type(
+            name=data_utils.rand_name('original_share_type_for_migration'),
+            cleanup_in_class=True,
+            extra_specs=utils.get_configured_extra_specs())
         cls.share_type_id = cls.share_type['id']
 
         cls.new_type = cls.create_share_type(
@@ -89,9 +92,9 @@ class MigrationBase(base.BaseSharesAdminTest):
     def _setup_migration(self, share, opposite=False):
 
         if opposite:
-            dest_type = self.new_type_opposite['share_type']
+            dest_type = self.new_type_opposite
         else:
-            dest_type = self.new_type['share_type']
+            dest_type = self.new_type
 
         dest_pool = utils.choose_matching_backend(share, self.pools, dest_type)
 
@@ -265,7 +268,7 @@ class MigrationBase(base.BaseSharesAdminTest):
         else:
             new_share_network_id = None
 
-        new_share_type_id = self.new_type['share_type']['id']
+        new_share_type_id = self.new_type['id']
         return task_state, new_share_network_id, new_share_type_id
 
     def _validate_snapshot(self, share, snapshot1, snapshot2):
@@ -295,13 +298,13 @@ class MigrationBase(base.BaseSharesAdminTest):
         ss_type, no_ss_type = self._create_share_type_for_snapshot_capability()
 
         if snapshot_capable:
-            share_type = ss_type['share_type']
-            share_type_id = no_ss_type['share_type']['id']
-            new_share_type_id = ss_type['share_type']['id']
+            share_type = ss_type
+            share_type_id = no_ss_type['id']
+            new_share_type_id = ss_type['id']
         else:
-            share_type = no_ss_type['share_type']
-            share_type_id = ss_type['share_type']['id']
-            new_share_type_id = no_ss_type['share_type']['id']
+            share_type = no_ss_type
+            share_type_id = ss_type['id']
+            new_share_type_id = no_ss_type['id']
 
         share = self.create_share(
             self.protocol, share_type_id=share_type_id)
@@ -338,7 +341,10 @@ class MigrationBase(base.BaseSharesAdminTest):
         # Share type with snapshot support
         st_name = data_utils.rand_name(
             'snapshot_capable_share_type_for_migration')
-        extra_specs = self.add_extra_specs_to_dict({"snapshot_support": True})
+        extra_specs = self.add_extra_specs_to_dict({
+            "snapshot_support": True,
+            "create_share_from_snapshot_support": True,
+        })
         ss_type = self.create_share_type(st_name, extra_specs=extra_specs)
 
         # New share type with no snapshot support capability
@@ -366,7 +372,7 @@ class MigrationCancelNFSTest(MigrationBase):
 
     @decorators.idempotent_id('d39dfa1b-6e91-4efc-84f1-76f878b51f2a')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @ddt.data(True, False)
     def test_migration_cancel(self, force_host_assisted):
         self._check_migration_enabled(force_host_assisted)
@@ -404,7 +410,7 @@ class MigrationCancelNFSTest(MigrationBase):
 
     @decorators.idempotent_id('640dce56-2084-488d-8dea-456840ff397e')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(
         CONF.share.run_snapshot_tests, 'Snapshot tests are disabled.')
     @testtools.skipUnless(
@@ -440,7 +446,7 @@ class MigrationOppositeDriverModesNFSTest(MigrationBase):
 
     @decorators.idempotent_id('d8cce50d-e8da-4fbc-8f94-0827bf277b6c')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @ddt.data(True, False)
     def test_migration_opposite_driver_modes(self, force_host_assisted):
         self._check_migration_enabled(force_host_assisted)
@@ -466,7 +472,7 @@ class MigrationOppositeDriverModesNFSTest(MigrationBase):
 
         old_share_network_id = share['share_network_id']
         old_share_type_id = share['share_type']
-        new_share_type_id = self.new_type_opposite['share_type']['id']
+        new_share_type_id = self.new_type_opposite['id']
 
         task_state = (constants.TASK_STATE_DATA_COPYING_COMPLETED
                       if force_host_assisted
@@ -508,7 +514,7 @@ class MigrationTwoPhaseNFSTest(MigrationBase):
 
     @decorators.idempotent_id('e6cf0e4d-bdf3-49c1-b6ba-56d1ad6c81d2')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @ddt.data(True, False)
     def test_migration_2phase(self, force_host_assisted):
         self._check_migration_enabled(force_host_assisted)
@@ -560,7 +566,7 @@ class MigrationWithShareExtendingNFSTest(MigrationBase):
 
     @decorators.idempotent_id('0e3d75e0-385a-4f7a-889f-2a3db79db8c2')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(
         CONF.share.run_extend_tests, 'Extend share tests are disabled.')
     @ddt.data(True, False)
@@ -574,7 +580,7 @@ class MigrationWithShareShrinkingNFSTest(MigrationBase):
 
     @decorators.idempotent_id('58c72e51-d217-48bc-8155-5a010912312e')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(
         CONF.share.run_shrink_tests, 'Shrink share tests are disabled.')
     @ddt.data(True, False)
@@ -588,7 +594,7 @@ class MigrationOfShareWithSnapshotNFSTest(MigrationBase):
 
     @decorators.idempotent_id('a95eb701-626a-4175-967b-4880d3716857')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(
         CONF.share.run_snapshot_tests, 'Snapshot tests are disabled.')
     @testtools.skipUnless(
@@ -601,7 +607,7 @@ class MigrationOfShareWithSnapshotNFSTest(MigrationBase):
         ss_type, __ = self._create_share_type_for_snapshot_capability()
 
         share = self.create_share(self.protocol,
-                                  share_type_id=ss_type['share_type']['id'],
+                                  share_type_id=ss_type['id'],
                                   cleanup_in_class=False)
         share = self.shares_v2_client.get_share(share['id'])
 
@@ -616,7 +622,7 @@ class MigrationOfShareWithSnapshotNFSTest(MigrationBase):
         share = self.migrate_share(
             share['id'], dest_pool,
             wait_for_status=task_state,
-            new_share_type_id=ss_type['share_type']['id'],
+            new_share_type_id=ss_type['id'],
             new_share_network_id=new_share_network_id, preserve_snapshots=True)
 
         share = self.migration_complete(share['id'], dest_pool)
@@ -630,7 +636,7 @@ class MigrationWithDifferentSnapshotSupportNFSTest(MigrationBase):
 
     @decorators.idempotent_id('a18b3637-2070-4a1b-acd9-c392eb7963b5')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(CONF.share.run_snapshot_tests,
                           'Snapshot tests are disabled.')
     @ddt.data(True, False)
@@ -643,7 +649,7 @@ class MigrationWithDifferentSnapshotSupportNFSTest(MigrationBase):
 
     @decorators.idempotent_id('59313673-6576-4163-ab96-41bafcdad63a')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
-    @utils.skip_if_microversion_lt("2.29")
+    @utils.skip_if_microversion_not_supported("2.29")
     @testtools.skipUnless(CONF.share.run_snapshot_tests,
                           'Snapshot tests are disabled.')
     @ddt.data(True, False)
