@@ -56,7 +56,7 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
         cls.user_id = cls.client.user_id
         cls.tenant_id = cls.client.tenant_id
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
         # create share group type
         cls.share_group_type = cls._create_share_group_type()
@@ -285,7 +285,7 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data('show', 'reset', 'update')
     @decorators.idempotent_id('cf45eb7d-7330-4b2d-8214-e4149eb4a398')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt("2.39")
+    @utils.skip_if_microversion_not_supported("2.39")
     def test_share_type_quotas_using_nonexistent_share_type(self, op):
 
         kwargs = {"share_type": "fake_nonexistent_share_type"}
@@ -301,9 +301,9 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data('id', 'name')
     @decorators.idempotent_id('2ba641a1-100b-417e-80e2-d3f717fd3c7c')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt("2.39")
+    @utils.skip_if_microversion_not_supported("2.39")
     def test_try_update_share_type_quota_for_share_networks(self, key):
-        share_type = self._create_share_type()
+        share_type = self.create_share_type()
         tenant_quotas = self.client.show_quotas(self.tenant_id)
 
         # Try to set 'share_networks' quota for share type
@@ -316,9 +316,9 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data('share_groups', 'share_group_snapshots')
     @decorators.idempotent_id('5eb6ce15-1172-4bcb-9c7b-91543bf714e8')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt(SHARE_GROUPS_MICROVERSION)
+    @utils.skip_if_microversion_not_supported(SHARE_GROUPS_MICROVERSION)
     def test_try_update_share_type_quota_for_share_groups(self, quota_name):
-        share_type = self._create_share_type()
+        share_type = self.create_share_type()
         tenant_quotas = self.client.show_quotas(self.tenant_id)
 
         self.assertRaises(lib_exc.BadRequest,
@@ -366,9 +366,9 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data('show', 'reset', 'update')
     @decorators.idempotent_id('acc609c2-f314-4540-984c-33e93d048f6c')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt("2.38")
+    @utils.skip_if_microversion_not_supported("2.38")
     def test_share_type_quotas_using_too_old_microversion(self, op):
-        share_type = self._create_share_type()
+        share_type = self.create_share_type()
         kwargs = {"version": "2.38", "share_type": share_type["name"]}
         if op == 'update':
             tenant_quotas = self.client.show_quotas(self.tenant_id)
@@ -382,9 +382,9 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data('show', 'reset', 'update')
     @decorators.idempotent_id('719768d1-d313-40e9-9127-c5777840ecbd')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt("2.39")
+    @utils.skip_if_microversion_not_supported("2.39")
     def test_quotas_providing_share_type_and_user_id(self, op):
-        share_type = self._create_share_type()
+        share_type = self.create_share_type()
         kwargs = {"share_type": share_type["name"], "user_id": self.user_id}
         if op == 'update':
             tenant_quotas = self.client.show_quotas(self.tenant_id)
@@ -398,9 +398,9 @@ class SharesAdminQuotasNegativeTest(base.BaseSharesAdminTest):
     @ddt.data(11, -1)
     @decorators.idempotent_id('82256511-aa46-4b99-a6e5-8b400534e96d')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
-    @utils.skip_if_microversion_lt("2.39")
+    @utils.skip_if_microversion_not_supported("2.39")
     def test_update_share_type_quotas_bigger_than_project_quota(self, st_q):
-        share_type = self._create_share_type()
+        share_type = self.create_share_type()
         self.update_quotas(self.tenant_id, shares=10)
 
         self.assertRaises(lib_exc.BadRequest,
@@ -446,7 +446,8 @@ class ReplicaQuotasNegativeTest(rep_neg_test.ReplicationNegativeBase):
         if not CONF.share.run_quota_tests:
             msg = "Quota tests are disabled."
             raise cls.skipException(msg)
-        utils.check_skip_if_microversion_lt(SHARE_REPLICA_QUOTAS_MICROVERSION)
+        utils.check_skip_if_microversion_not_supported(
+            SHARE_REPLICA_QUOTAS_MICROVERSION)
 
     def _modify_quotas_for_test(self, quota_key, new_limit):
         kwargs = {quota_key: new_limit}
