@@ -16,11 +16,13 @@
 import ddt
 from tempest import config
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
 import testtools
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests import share_exceptions
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests import utils
@@ -29,16 +31,19 @@ CONF = config.CONF
 LATEST_MICROVERSION = CONF.share.max_api_microversion
 
 
-@base.skip_if_microversion_lt("2.49")
-@testtools.skipUnless(
-    CONF.share.multitenancy_enabled,
-    'Multitenancy tests are disabled')
-@testtools.skipUnless(
-    CONF.share.run_manage_unmanage_tests,
-    'Manage/unmanage tests are disabled.')
 @ddt.ddt
 class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
 
+    @classmethod
+    def skip_checks(cls):
+        super(ManageShareServersNegativeTest, cls).skip_checks()
+        if not CONF.share.multitenancy_enabled:
+            raise cls.skipException('Multitenancy tests are disabled.')
+        if not CONF.share.run_manage_unmanage_tests:
+            raise cls.skipException('Manage/unmanage tests are disabled.')
+
+        utils.check_skip_if_microversion_not_supported('2.49')
+
     @classmethod
     def resource_setup(cls):
         super(ManageShareServersNegativeTest, cls).resource_setup()
@@ -67,7 +72,7 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
             cleanup_in_class=True
         )
         share = self.create_share(
-            share_type_id=self.share_type['share_type']['id'],
+            share_type_id=self.share_type['id'],
             share_network_id=share_network['id']
         )
         return self.shares_v2_client.get_share(share['id'])
@@ -78,6 +83,7 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         ('share_network_subnet_id', 'invalid_share_network_subnet_id'),
     )
     @ddt.unpack
+    @decorators.idempotent_id('60b94091-f35d-42ac-a25a-ca1f7e66bb44')
     @testtools.skipIf(CONF.share.share_network_id != "",
                       "This test is not suitable for pre-existing "
                       "share_network.")
@@ -128,6 +134,7 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share server
         self._delete_share_server_and_wait(managed_share_server['id'])
 
+    @decorators.idempotent_id('0f21aebe-e983-4112-a494-b287293112d2')
     @testtools.skipIf(CONF.share.share_network_id != "",
                       "This test is not suitable for pre-existing "
                       "share_network.")
@@ -158,9 +165,9 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
                 share['share_server_id'],
                 status=constants.SERVER_STATE_ACTIVE,
             )
-            self.shares_v2_client.wait_for_share_server_status(
-                share['share_server_id'],
-                constants.SERVER_STATE_ACTIVE,
+            waiters.wait_for_resource_status(
+                self.shares_v2_client, share['share_server_id'],
+                constants.SERVER_STATE_ACTIVE, resource_name='share_server'
             )
 
         # delete share
@@ -169,6 +176,7 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share server
         self._delete_share_server_and_wait(share['share_server_id'])
 
+    @decorators.idempotent_id('84f9a808-8bff-4652-8877-4c9f0dfeed8a')
     @testtools.skipIf(CONF.share.share_network_id != "",
                       "This test is not suitable for pre-existing "
                       "share_network.")
@@ -199,9 +207,9 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
                 share['share_server_id'],
                 status=constants.SERVER_STATE_ACTIVE,
             )
-            self.shares_v2_client.wait_for_share_server_status(
-                share['share_server_id'],
-                constants.SERVER_STATE_ACTIVE,
+            waiters.wait_for_resource_status(
+                self.shares_v2_client, share['share_server_id'],
+                constants.SERVER_STATE_ACTIVE, resource_name='share_server'
             )
 
         # delete share
@@ -210,12 +218,13 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share server
         self._delete_share_server_and_wait(share['share_server_id'])
 
+    @decorators.idempotent_id('fbe6cf2d-3e33-40d8-b420-b785d3cb7559')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_share_server_reset_state_invalid_state(self):
 
         # create share
         share = self.create_share(
-            share_type_id=self.share_type['share_type']['id'])
+            share_type_id=self.share_type['id'])
         share = self.shares_v2_client.get_share(share['id'])
 
         # try to change it to wrong state
@@ -229,12 +238,13 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share
         self._delete_share_and_wait(share)
 
+    @decorators.idempotent_id('c0a13fc4-9f30-483a-b473-0f0ce533f645')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_unmanage_share_server_with_share(self):
 
         # create share
         share = self.create_share(
-            share_type_id=self.share_type['share_type']['id'])
+            share_type_id=self.share_type['id'])
         share = self.shares_v2_client.get_share(share['id'])
 
         # try to unmanage
@@ -247,6 +257,7 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share
         self._delete_share_and_wait(share)
 
+    @decorators.idempotent_id('d2feb338-5c78-4370-b5ba-c8b16df63b43')
     @testtools.skipIf(CONF.share.share_network_id != "",
                       "This test is not suitable for pre-existing "
                       "share_network.")
@@ -296,12 +307,13 @@ class ManageShareServersNegativeTest(base.BaseSharesAdminTest):
         # delete share server
         self._delete_share_server_and_wait(managed_share_server['id'])
 
+    @decorators.idempotent_id('30606085-4b01-4489-a18c-22e67ed0e221')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_manage_share_server_double_manage(self):
 
         # create share
         share = self.create_share(
-            share_type_id=self.share_type['share_type']['id'])
+            share_type_id=self.share_type['id'])
         share = self.shares_v2_client.get_share(share['id'])
 
         share_server = self.shares_v2_client.show_share_server(
