@@ -40,7 +40,7 @@ class ExtraSpecsReadAdminTest(base.BaseSharesAdminTest):
         cls.share_type = cls.create_share_type(
             cls.share_type_name, extra_specs=cls.required_extra_specs)
 
-        cls.st_id = cls.share_type["share_type"]["id"]
+        cls.st_id = cls.share_type["id"]
         cls.custom_extra_specs = {"key1": "value1", "key2": "value2"}
         cls.expected_extra_specs = copy.copy(cls.custom_extra_specs)
         cls.expected_extra_specs.update(cls.required_extra_specs)
@@ -77,7 +77,7 @@ class ExtraSpecsWriteAdminTest(base.BaseSharesAdminTest):
         self.share_type = self.create_share_type(
             self.share_type_name, extra_specs=self.required_extra_specs)
 
-        self.st_id = self.share_type['share_type']['id']
+        self.st_id = self.share_type['id']
 
         # Create extra specs for share type
         self.shares_client.create_share_type_extra_specs(
@@ -128,12 +128,25 @@ class ExtraSpecsWriteAdminTest(base.BaseSharesAdminTest):
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     @ddt.data(*utils.deduplicate(['2.24', LATEST_MICROVERSION]))
     def test_delete_snapshot_support_extra_spec(self, version):
-        utils.skip_if_microversion_not_supported(version)
-        # Delete one extra spec for share type
+        """Is snapshot_support really an optional extra-spec if API > v2.24?"""
+        utils.check_skip_if_microversion_not_supported(version)
+
+        # set snapshot_support extra-spec
+        self.shares_v2_client.update_share_type_extra_specs(
+            self.st_id, {'snapshot_support': 'True'})
+
+        # Get extra specs
+        share_type_extra_specs = self.shares_client.get_share_type_extra_specs(
+            self.st_id)
+
+        self.assertIn('snapshot_support', share_type_extra_specs)
+        self.assertEqual('True', share_type_extra_specs['snapshot_support'])
+
+        # Delete the 'snapshot_support' extra spec from the share type
         self.shares_v2_client.delete_share_type_extra_spec(
             self.st_id, 'snapshot_support', version=version)
 
-        # Get metadata
+        # Get extra specs
         share_type_extra_specs = self.shares_client.get_share_type_extra_specs(
             self.st_id)
 
