@@ -96,7 +96,7 @@ class ShareIpRulesForNFSTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(ShareIpRulesForNFSTest, cls).resource_setup()
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
         # create share
@@ -261,7 +261,7 @@ class ShareUserRulesForNFSTest(base.BaseSharesMixedTest):
         super(ShareUserRulesForNFSTest, cls).resource_setup()
 
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
         # create share
@@ -363,7 +363,7 @@ class ShareCertRulesForGLUSTERFSTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(ShareCertRulesForGLUSTERFSTest, cls).resource_setup()
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
         # create share
@@ -492,7 +492,7 @@ class ShareCephxRulesForCephFSTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(ShareCephxRulesForCephFSTest, cls).resource_setup()
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
         # create share
@@ -586,7 +586,7 @@ class ShareRulesTest(base.BaseSharesMixedTest):
         cls.access_type, cls.access_to = (
             cls._get_access_rule_data_from_config()
         )
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
         cls.share = cls.create_share(share_type_id=cls.share_type_id)
 
@@ -595,7 +595,7 @@ class ShareRulesTest(base.BaseSharesMixedTest):
     @ddt.data(*utils.deduplicate(
         ['1.0', '2.9', '2.27', '2.28', '2.45', LATEST_MICROVERSION]))
     def test_list_access_rules(self, version):
-        utils.skip_if_microversion_not_supported(version)
+        utils.check_skip_if_microversion_not_supported(version)
         if (utils.is_microversion_lt(version, '2.13') and
                 CONF.share.enable_cephx_rules_for_protocols):
             msg = ("API version %s does not support cephx access type, need "
