@@ -21,6 +21,7 @@ from testtools import testcase as tc
 
 from manila_tempest_tests import share_exceptions
 from manila_tempest_tests.tests.api import base
+from manila_tempest_tests import utils
 
 CONF = config.CONF
 
@@ -31,7 +32,12 @@ class SharesNegativeTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(SharesNegativeTest, cls).resource_setup()
         # create share_type
-        cls.share_type = cls._create_share_type()
+        extra_specs = {}
+        if CONF.share.capability_snapshot_support:
+            extra_specs.update({'snapshot_support': True})
+        if CONF.share.capability_create_share_from_snapshot_support:
+            extra_specs.update({'create_share_from_snapshot_support': True})
+        cls.share_type = cls.create_share_type(extra_specs=extra_specs)
         cls.share_type_id = cls.share_type['id']
 
     @decorators.idempotent_id('b9bb8dee-0c7c-4e51-909c-028335b1a6a0')
@@ -60,7 +66,6 @@ class SharesNegativeTest(base.BaseSharesMixedTest):
         "Create share from snapshot tests are disabled.")
     def test_create_share_from_snap_with_less_size(self):
         # requires minimum 5Gb available space
-
         skip_msg = "Check disc space for this test"
 
         try:  # create share
@@ -145,9 +150,9 @@ class SharesAPIOnlyNegativeTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(SharesAPIOnlyNegativeTest, cls).resource_setup()
         # create share_type
-        cls.share_type = cls._create_share_type()
-        cls.share_type_min_2_max_5 = cls._create_share_type(
-            specs={
+        cls.share_type = cls.create_share_type()
+        cls.share_type_min_2_max_5 = cls.create_share_type(
+            extra_specs={
                 'provisioning:max_share_size': int(CONF.share.share_size) + 4,
                 'provisioning:min_share_size': int(CONF.share.share_size) + 1
             })
@@ -283,7 +288,7 @@ class SharesAPIOnlyNegativeTest(base.BaseSharesMixedTest):
         self.assertRaises(lib_exc.NotFound,
                           self.shares_client.delete_share, '')
 
-    @base.skip_if_microversion_lt("2.61")
+    @utils.skip_if_microversion_not_supported("2.61")
     @decorators.idempotent_id('b8097d56-067e-4d7c-8401-31bc7021fe86')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
     def test_create_share_size_greater_than_specified_in_share_type(self):
@@ -293,7 +298,7 @@ class SharesAPIOnlyNegativeTest(base.BaseSharesMixedTest):
                           size=int(CONF.share.share_size) + 5,
                           share_type_id=self.share_type_min_2_max_5_id)
 
-    @base.skip_if_microversion_lt("2.61")
+    @utils.skip_if_microversion_not_supported("2.61")
     @decorators.idempotent_id('b8097d56-067e-4d7c-8401-31bc7021fe87')
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
     def test_create_share_size_less_than_specified_in_share_type(self):
