@@ -44,14 +44,17 @@ class SnapshotIpRulesForNFSNegativeTest(
             msg = "IP rule tests for %s protocol are disabled." % cls.protocol
             raise cls.skipException(msg)
 
-        utils.check_skip_if_microversion_lt('2.32')
+        utils.check_skip_if_microversion_not_supported('2.32')
 
     @classmethod
     def resource_setup(cls):
         super(SnapshotIpRulesForNFSNegativeTest, cls).resource_setup()
         # create share type
-        extra_specs = {'mount_snapshot_support': 'True'}
-        cls.share_type = cls._create_share_type(specs=extra_specs)
+        extra_specs = {
+            'snapshot_support': True,
+            'mount_snapshot_support': True,
+        }
+        cls.share_type = cls.create_share_type(extra_specs=extra_specs)
         cls.share_type_id = cls.share_type['id']
         # create share
         cls.share = cls.create_share(cls.protocol,
